@@ -1,5 +1,3 @@
-from launchable.testpath import FilePathNormalizer, parse_test_path, unparse_test_path
-
 import os.path
 import pathlib
 import subprocess
@@ -7,6 +5,9 @@ import sys
 import tempfile
 import unittest
 
+from launchable.testpath import (FilePathNormalizer,
+                                 parse_test_path, unparse_test_path)
+
 
 class TestPathEncodingTest(unittest.TestCase):
     def test_parse(self):
